summaryrefslogtreecommitdiffstats
path: root/openpgp/src/lib.rs
diff options
context:
space:
mode:
authorJustus Winter <justus@sequoia-pgp.org>2019-11-28 15:27:33 +0100
committerJustus Winter <justus@sequoia-pgp.org>2019-11-28 16:26:43 +0100
commitbbbc6da375d6584c7b2bcc74e838fff943f489d4 (patch)
tree0a965698c96dbc0fc8541c6adc2224935b68bc07 /openpgp/src/lib.rs
parentf53c77752ff04c3713c175a76a06723042e681ae (diff)
Call TPKs Certificates, update identifiers, documentation.
- Fixes #387.
Diffstat (limited to 'openpgp/src/lib.rs')
-rw-r--r--openpgp/src/lib.rs16
1 files changed, 8 insertions, 8 deletions
diff --git a/openpgp/src/lib.rs b/openpgp/src/lib.rs
index dfc04ab2..e001276c 100644
--- a/openpgp/src/lib.rs
+++ b/openpgp/src/lib.rs
@@ -128,8 +128,8 @@ use crate::packet::{Container, key};
pub mod parse;
-pub mod tpk;
-pub use tpk::TPK;
+pub mod cert;
+pub use cert::Cert;
pub mod serialize;
mod packet_pile;
@@ -245,16 +245,16 @@ pub enum Error {
MalformedMessage(String),
/// Malformed tranferable public key.
- #[fail(display = "Malformed TPK: {}", _0)]
- MalformedTPK(String),
+ #[fail(display = "Malformed Cert: {}", _0)]
+ MalformedCert(String),
- /// Unsupported TPK.
+ /// Unsupported Cert.
///
/// This usually occurs, because the primary key is in an
/// unsupported format. In particular, Sequoia does not support
/// version 3 keys.
- #[fail(display = "Unsupported TPK: {}", _0)]
- UnsupportedTPK(String),
+ #[fail(display = "Unsupported Cert: {}", _0)]
+ UnsupportedCert(String),
/// Index out of range.
#[fail(display = "Index out of range")]
@@ -385,7 +385,7 @@ impl Packet {
/// [`PacketPileParser`], or [`PacketPile::from_file`] (or related
/// routines).
///
/// Normally, you'll want to convert the `PacketPile` to a TPK or a
/// `Message`.
///
/// [`PacketParser`]: parse/struct.PacketParser.html
@@ -385,7 +385,7 @@ impl Packet {
/// routines).
///
-/// Normally, you'll want to convert the `PacketPile` to a TPK or a
+/// Normally, you'll want to convert the `PacketPile` to a Cert or a
/// `Message`.
///